const {
  Scene,
  Object3D,
  PerspectiveCamera,
  WebGLRenderer,
  CanvasTexture,
  Sprite,
  SpriteMaterial,
  loadTexture,
  ImageUtils,
  PointLight,
  SpriteAlignment,
  shadowMap,
  BufferGeometry,
  BufferGeometryUtils,
  CubeTextureLoader,
  MultiMaterial,
  vertices
} = THREE;

import {TerrainGenerator} from './TerrainGenerator.js';
import { getData } from './getData.js';
import { Enum } from './Texture.js';
import fragmentShader from './fragmentShader';
import vertexShader from './vertexShader';

// Tweakables
const scaleFactor = 5; // HiDPI
const width = window.innerWidth * scaleFactor;

const height = window.innerHeight * scaleFactor;
const rotationSensitivity = 0.04;
const rotationIncrement = -0.2;

console.log(window.innerWidth,window.innerHeight )

// Returns a color for a given datum and number of clusters.
const camera = new PerspectiveCamera(20, width / height, 1, 100000);
const renderer = new WebGLRenderer({ antialias: true, alpha: false
                                   });

renderer.setSize(width, height);
document.body.appendChild(renderer.domElement);
renderer.domElement.style.width = width / scaleFactor + 'px';
renderer.domElement.style.height = height / scaleFactor + 'px';




var controls = new THREE.OrbitControls(camera, renderer.domElement);


const scene = new Scene();

console.log(renderer.info);
renderer.info.autoReset = false;
renderer.info.reset();

//GROUND
const groundWidth = 10;
const groundHeight = 10;
var groundTexture = new THREE.TextureLoader().load(
  'https://raw.githubusercontent.com/stemkoski/stemkoski.github.com/master/Three.js/images/checkerboard.jpg'
);
groundTexture.wrapS = groundTexture.wrapT = THREE.RepeatWrapping;
groundTexture.repeat.set(groundWidth/4, groundHeight/4);
var groundMaterial = new THREE.MeshBasicMaterial({
  map: groundTexture,
  side: THREE.DoubleSide
});
var groundGeometry = new THREE.PlaneGeometry(groundWidth, groundHeight);
var ground = new THREE.Mesh(groundGeometry, groundMaterial);
scene.add(ground);



const csvUrl = 'https://github.com/meperezcuello/dataviz-project-template-proposal/blob/master/azeroth_31_26_heighmap.png';
const csvUrl2 = 'https://gist.githubusercontent.com/meperezcuello/eb1f6c7dabe63443aa1dafa169e51d07/raw/1c7e70db4548e8ce7eaf9c9ba21391681462651c/mountain.csv'
//** Custom Texture Mapping **//
//
//let dict3 = ['12'];
//console.log(dict3[0]);

let dict = [
    {texture:'oceanTexture', repeatedness: 5, smoothing: [0.01, 0.50]}, //<-- this is bottom texture
    {texture:'sandyTexture', repeatedness: 20, smoothing: [0.50, 0.55]},
    {texture:'snowyTexture', repeatedness: 20, smoothing: [0.55, 0.65]},
    {texture:'snowyTexture', repeatedness: 10, smoothing: [0.65, 0.75]},
    {texture:'snowyTexture', repeatedness: 20, smoothing: [0.75, 0.99]}, // <-- this is top texture
  ];

let wow = [
    {texture:'wowtest', repeatedness: 1, smoothing: [0.01, 0.01]}, //<-- this is bottom texture
  ];
  
let wow2 = [
    {texture:'wowtest2', repeatedness: 1, smoothing: [0.01, 0.01]}, //<-- this is bottom texture
  ];
  
const TerrainMain = async() => {
  //const terrain =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/images/heigmaps_testing_2_08.gif')
  //terrain.loadMaterials(dict);
  //terrain.mesh(scene)
}




https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/entire_optimized.png

(async() => {
  
  const post_x = 0
  const pos_z = 0
	 
  const Darkshore =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0003_Darkshore_h.png')
  Darkshore.loadMaterials('Darkshore')
  Darkshore.mesh(scene, post_x, pos_z);
  
  const Teldrassil =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0001_Teldrassil_h.png');
  Teldrassil.loadMaterials('Teldrassil');
  Teldrassil.mesh(scene, post_x, pos_z);
  
  const Moonglade =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0004_Moonglade_h.png');
  Moonglade.loadMaterials('Moonglade');
  Moonglade.mesh(scene, post_x, pos_z);
  
  const Winterspring =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0007_Winterspring_h.png');
  Winterspring.loadMaterials('Winterspring');
  Winterspring.mesh(scene, post_x, pos_z);
  
  const Mount_hyjal =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0011_Mount_hyjal_h.png ');
  Mount_hyjal.loadMaterials('Mount_hyjal');
  Mount_hyjal.mesh(scene, post_x, pos_z);
  
  const Ashenvale = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0013_Ashenvale_h.png');
  Ashenvale.loadMaterials('Ashenvale');
  Ashenvale.mesh(scene, post_x, pos_z);
  
  const Azhara = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0015_Azhara_h.png');
  Azhara.loadMaterials('Azhara');
  Azhara.mesh(scene, post_x, pos_z);
  
  const Stonetalon_mountains = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0017_Stonetalon_mountains_h.png');
  Stonetalon_mountains.loadMaterials('Stonetalon_mountains');
  Stonetalon_mountains.mesh(scene, post_x, pos_z);
  
  const Durotar = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0019_Durotar_h.png');
  Durotar.loadMaterials('Durotar');
  Durotar.mesh(scene, post_x, pos_z);
  
  const Desolance = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0021_Desolance_h.png');
  Desolance.loadMaterials('Desolance');
  Desolance.mesh(scene, post_x, pos_z);
  
  const Northen_Barrens = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0023_Northen_Barrens_h.png');
  Northen_Barrens.loadMaterials('Northen_Barrens');
  Northen_Barrens.mesh(scene, post_x, pos_z);
  
  const Dustwallo_Marsh = new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/test2/_0025_Dustwallo-Marsh_h.png');
  Dustwallo_Marsh.loadMaterials('Dustwallo_Marsh');
  Dustwallo_Marsh.mesh(scene, post_x, pos_z);
  
  
  //const mesh = await TerrainMain();


  //console.log(mesh)
  // mesh.rotation.x = -Math.PI / 2;
  // mesh.position.y = 0;

 		//scene.add(mesh);
//mesh.receiveShadow = true;

  const waterCube = new THREE.BoxGeometry(1000, 616, 1);
  
  const water = new THREE.Mesh(waterCube, new THREE.MeshBasicMaterial({color:0x001d28, transparent: true, opacity: 0.80, side: THREE.DoubleSide}));
 	scene.add(water);
water.rotation.x = -Math.PI / 2;
water.position.y = 27.2;
water.receiveShadow = true;


//LIGHT
  const light = new THREE.PointLight(0xffffff, 2, 350);
  light.position.set(105, 100, 15);
  light.castShadow = true;
  light.shadow.camera.near = 0.3;
  light.shadow.camera.far = 25;
  scene.add(light);



//Init ground roration
const epsilon = -0.5;
ground.rotation.x -= Math.PI / 2;
ground.position.z = groundWidth/2 + epsilon;
ground.position.x = groundHeight/2 + epsilon;
ground.position.y = epsilon;


var axesHelper = new THREE.AxesHelper( 100 );
scene.add( axesHelper );
//Init camera position
//camera.rotation.x = Math.PI/2;
camera.position.set(300, 800, -800);


      function onDocumentKeyDown(event) {
    var keyCode = event.which;
    if (keyCode === 38) {
        console.log('hgg');
    }};

  window.addEventListener("keydown", onDocumentKeyDown, false);

const animate = () => {
  	//water.rotation.z -= 0.025;
   	//mesh.rotation.z -= 0.025;

    requestAnimationFrame(animate);
 		controls.update();
	  renderer.render(scene, camera);
};
  
  //dispose from memeory
//renderer.renderLists.dispose();
//mesh.geometry.dispose();
//mesh.material.dispose();
//scene.remove( mesh );

  
animate();
  })()